@@ -1,5 +1,5 @@
-package Pod::Weaver::PluginBundle::Author::IOANR;
-$Pod::Weaver::PluginBundle::Author::IOANR::VERSION = '1.162691';
+package Pod::Weaver::PluginBundle::Author::IOANR 1.172320;
+
 # ABSTRACT: Weave the POD for a IOANR dist
 
 use Moose;
@@ -81,7 +81,7 @@ Pod::Weaver::PluginBundle::Author::IOANR - Weave the POD for a IOANR dist
 
 =head1 VERSION
 
-version 1.162691
+version 1.172320
 
 =head1 SEE ALSO
 
@@ -112,7 +112,7 @@ Ioan Rogers <ioanr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Ioan Rogers.
+This software is Copyright (c) 2017 by Ioan Rogers.
 
 This is free software, licensed under:
 
